==> ppcboot-1.0.3.tar.bz2: ppcboot-1.0.3/board/esd/adciop/adciop.c <==
/*
 * (C) Copyright 2000
 * Wolfgang Denk, DENX Software Engineering, wd@denx.de.
 *
 * See file CREDITS for list of people who contributed to this
 * project.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

#include <ppcboot.h>
#include "adciop.h"

/* ------------------------------------------------------------------------- */

#define	_NOT_USED_	0xFFFFFFFF

/* ------------------------------------------------------------------------- */


int board_pre_init (void)
{
  /*
   * Set port pin in escc2 to keep living
   */
  *(unsigned char *)0x2000033e = 0xf7;   /* ESCC2: PCR */
  *(unsigned char *)0x2000033c = 0x08;   /* ESCC2: PVR */

  return 0;
}


/*
 * Check Board Identity:
 */

int checkboard (void)
{
    unsigned char *s = getenv("serial#");
    unsigned char *e;
    int l_type;

    if (!s || strncmp(s, "ADCIOP", 6)) {
	printf ("### No HW ID - assuming ADCIOP\n");
	return (1);
    }

    l_type = (*(s+6) == 'L');

    for (e=s; *e; ++e) {
	if (*e == ' ')
	    break;
    }

    for ( ; s<e; ++s) {
	putc (*s);
    }
    putc ('\n');

    return (l_type);
}

/* ------------------------------------------------------------------------- */

long int initdram (int board_type)
{
    return (16 * 1024*1024);
}

/* ------------------------------------------------------------------------- */

int testdram (void)
{
    /* TODO: XXX XXX XXX */
    printf ("test: 16 MB - ok\n");

    return (0);
}

/* ------------------------------------------------------------------------- */

==> ppcboot-1.1.1.tar.bz2: ppcboot-1.1.1/board/esd/adciop/adciop.c <==
/*
 * (C) Copyright 2000
 * Wolfgang Denk, DENX Software Engineering, wd@denx.de.
 *
 * See file CREDITS for list of people who contributed to this
 * project.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

#include <ppcboot.h>
#include "adciop.h"

/* ------------------------------------------------------------------------- */

#define	_NOT_USED_	0xFFFFFFFF

/* ------------------------------------------------------------------------- */


int board_pre_init (void)
{
  /*
   * Set port pin in escc2 to keep living, and configure user led output
   */
  *(unsigned char *)0x2000033e = 0x77;   /* ESCC2: PCR bit3=pwr on, bit7=led out */
  *(unsigned char *)0x2000033c = 0x88;   /* ESCC2: PVR pwr on, led off */

  /*
   * Init pci regs
   */
  *(unsigned long *)0x50000304 = 0x02900007;  /* enable mem/io/master bits */
  *(unsigned long *)0x500001b4 = 0x00000000;  /* disable pci interrupt output enable */
  *(unsigned long *)0x50000354 = 0x00c05800;  /* disable emun interrupt output enable */
  *(unsigned long *)0x50000344 = 0x00000000;  /* disable pme interrupt output enable */
  *(unsigned long *)0x50000310 = 0x00000000;  /* pcibar0 */
  *(unsigned long *)0x50000314 = 0x00000000;  /* pcibar1 */
  *(unsigned long *)0x50000318 = 0x00000000;  /* pcibar2 */

  return 0;
}


/*
 * Check Board Identity:
 */

int checkboard (void)
{
    unsigned char *s = getenv("serial#");
    unsigned char *e;
    int l_type;

    if (!s || strncmp(s, "ADCIOP", 6)) {
	printf ("### No HW ID - assuming ADCIOP\n");
	return (1);
    }

    l_type = (*(s+6) == 'L');

    for (e=s; *e; ++e) {
	if (*e == ' ')
	    break;
    }

    for ( ; s<e; ++s) {
	putc (*s);
    }
    putc ('\n');

    return (l_type);
}

/* ------------------------------------------------------------------------- */

long int initdram (int board_type)
{
    return (16 * 1024*1024);
}

/* ------------------------------------------------------------------------- */

int testdram (void)
{
    /* TODO: XXX XXX XXX */
    printf ("test: 16 MB - ok\n");

    return (0);
}

/* ------------------------------------------------------------------------- */
